aboutsummaryrefslogtreecommitdiff
path: root/bdep/bdep.cxx
diff options
context:
space:
mode:
authorBoris Kolpackov <boris@codesynthesis.com>2018-03-13 10:34:57 +0200
committerBoris Kolpackov <boris@codesynthesis.com>2018-03-13 10:34:57 +0200
commit6be9c7746f92aa721782a4d0eaff5f901fc528cd (patch)
treead072fd130d3bb64acee0be183698daa328e8966 /bdep/bdep.cxx
parent5dcbecfd8b83f516c067780214f06321f03d1cce (diff)
Setup command line infrastructure for new command
Diffstat (limited to 'bdep/bdep.cxx')
-rw-r--r--bdep/bdep.cxx13
1 files changed, 7 insertions, 6 deletions
diff --git a/bdep/bdep.cxx b/bdep/bdep.cxx
index 39f08ad..ef4a6ec 100644
--- a/bdep/bdep.cxx
+++ b/bdep/bdep.cxx
@@ -22,9 +22,10 @@
//
#include <bdep/help.hxx>
-#include <bdep/config.hxx>
+#include <bdep/new.hxx>
#include <bdep/init.hxx>
#include <bdep/sync.hxx>
+#include <bdep/config.hxx>
using namespace std;
using namespace bdep;
@@ -34,11 +35,11 @@ using namespace bdep;
// Once this is done, use the "final" values of the common options to do
// global initializations (verbosity level, etc).
//
// If O is-a project_options, then also handle the @<cfg-name> arguments and
// place them into project_options::config_name.
//
static inline bool
-cfg_name (project_options* o, const char* a)
+cfg_name (configuration_name_options* o, const char* a)
{
string n (a);
@@ -264,10 +265,10 @@ try
break; \
}
- //COMMAND_IMPL (new_, new, "new");
- COMMAND_IMPL (config, config, "config");
+ COMMAND_IMPL (new_, new, "new");
COMMAND_IMPL (init, init, "init");
COMMAND_IMPL (sync, sync, "sync");
+ COMMAND_IMPL (config, config, "config");
assert (false);
fail << "unhandled command";
@@ -34,11 +35,11 @@ using namespace bdep;
// global initializations (verbosity level, etc).
//
-// If O is-a project_options, then also handle the @<cfg-name> arguments and
-// place them into project_options::config_name.
+// If O is-a configuration_name_options, then also handle the @<cfg-name>
+// arguments and place them into configuration_name_options::config_name.
//
static inline bool